from distutils.core import setup
setup(
	name='ifhotf',
	packages=['ifhotf'],
	version='0.1',
	description='for Iron Function(Hot function)',
	author='Eugene Gwon',
	author_email='eugenegwon@gmail.com',
	url='https://github.com/eugenegwon/ifhotf',
	download_url='https://github.com/eugenegwon/ifhotf/archive/0.1.tar.gz',
	keywords=['ironfunction'],
	classifiers=[],
)
